@@ -719,6 +719,12 @@ class Lateral(DerivedTable):
     arg_types = {"this": True, "outer": False, "alias": False}
 
 
+# Clickhouse FROM FINAL modifier
+# https://clickhouse.com/docs/en/sql-reference/statements/select/from/#final-modifier
+class Final(Expression):
+    pass
+
+
 class Offset(Expression):
     arg_types = {"this": False, "expression": True}
 
@@ -727,6 +733,20 @@ class Order(Expression):
     arg_types = {"this": False, "expressions": True}
 
 
+# hive specific sorts
+# https://cwiki.apache.org/confluence/display/Hive/LanguageManual+SortBy
+class Cluster(Order):
+    pass
+
+
+class Distribute(Order):
+    pass
+
+
+class Sort(Order):
+    pass
+
+
 class Ordered(Expression):
     arg_types = {"this": True, "desc": False}
 
@@ -911,6 +931,9 @@ class Select(Subqueryable, Expression):
         "having": False,
         "qualify": False,
         "window": False,
+        "distribute": False,
+        "sort": False,
+        "cluster": False,
         "order": False,
         "limit": False,
         "offset": False,
@@ -1364,6 +1387,9 @@ class Subquery(DerivedTable):
         "this": True,
         "alias": False,
         "joins": False,
+        "distribute": False,
+        "sort": False,
+        "cluster": False,
         "order": False,
         "limit": False,
         "offset": False,
@@ -1464,6 +1490,7 @@ class DataType(Expression):
         ARRAY = auto()
         MAP = auto()
         UUID = auto()
+        GEOGRAPHY = auto()
         STRUCT = auto()
 
     @classmethod
@@ -1862,22 +1889,54 @@ class CurrentDatetime(Func):
     arg_types = {"this": False}
 
 
+class CurrentTime(Func):
+    arg_types = {"this": False}
+
+
 class CurrentTimestamp(Func):
-    arg_types = {}
+    arg_types = {"this": False}
 
 
 class DateAdd(Func, TimeUnit):
     arg_types = {"this": True, "expression": True, "unit": False}
 
 
+class DateSub(Func, TimeUnit):
+    arg_types = {"this": True, "expression": True, "unit": False}
+
+
 class DateDiff(Func, TimeUnit):
     arg_types = {"this": True, "expression": True, "unit": False}
 
 
+class DateTrunc(Func, TimeUnit):
+    arg_types = {"this": True, "unit": True, "zone": False}
+
+
+class DatetimeAdd(Func, TimeUnit):
+    arg_types = {"this": True, "expression": True, "unit": False}
+
+
+class DatetimeSub(Func, TimeUnit):
+    arg_types = {"this": True, "expression": True, "unit": False}
+
+
 class DatetimeDiff(Func, TimeUnit):
     arg_types = {"this": True, "expression": True, "unit": False}
 
 
+class DatetimeTrunc(Func, TimeUnit):
+    arg_types = {"this": True, "unit": True, "zone": False}
+
+
+class TimestampAdd(Func, TimeUnit):
+    arg_types = {"this": True, "expression": True, "unit": False}
+
+
+class TimestampSub(Func, TimeUnit):
+    arg_types = {"this": True, "expression": True, "unit": False}
+
+
 class TimestampDiff(Func, TimeUnit):
     arg_types = {"this": True, "expression": True, "unit": False}
 
@@ -1886,12 +1945,16 @@ class TimestampTrunc(Func, TimeUnit):
     arg_types = {"this": True, "unit": True, "zone": False}
 
 
-class DateTrunc(Func, TimeUnit):
-    arg_types = {"this": True, "unit": True, "zone": False}
+class TimeAdd(Func, TimeUnit):
+    arg_types = {"this": True, "expression": True, "unit": False}
 
 
-class DatetimeTrunc(Func, TimeUnit):
-    arg_types = {"this": True, "unit": True, "zone": False}
+class TimeSub(Func, TimeUnit):
+    arg_types = {"this": True, "expression": True, "unit": False}
+
+
+class TimeDiff(Func, TimeUnit):
+    arg_types = {"this": True, "expression": True, "unit": False}
 
 
 class TimeTrunc(Func, TimeUnit):
@@ -1902,10 +1965,6 @@ class DateStrToDate(Func):
     pass
 
 
-class DateSub(Func, TimeUnit):
-    arg_types = {"this": True, "expression": True, "unit": False}
-
-
 class DateToDateStr(Func):
     pass
 
@@ -2074,6 +2133,11 @@ class StrToUnix(Func):
     arg_types = {"this": True, "format": True}
 
 
+class Struct(Func):
+    arg_types = {"expressions": True}
+    is_var_len_args = True
+
+
 class StructExtract(Func):
     arg_types = {"this": True, "expression": True}
 
