@@ -60,6 +60,7 @@ class Parser:
         TokenType.DATE,
         TokenType.DECIMAL,
         TokenType.UUID,
+        TokenType.GEOGRAPHY,
         *NESTED_TYPE_TOKENS,
     }
 
@@ -129,7 +130,9 @@ class Parser:
 
     FUNC_TOKENS = {
         TokenType.CURRENT_DATE,
+        TokenType.CURRENT_DATETIME,
         TokenType.CURRENT_TIMESTAMP,
+        TokenType.CURRENT_TIME,
         TokenType.EXTRACT,
         TokenType.FILTER,
         TokenType.FIRST,
@@ -617,7 +620,7 @@ class Parser:
                     )
                 )
 
-            if self._match_by(TokenType.PARTITION):
+            if self._match(TokenType.PARTITIONED_BY):
                 properties.append(
                     self.expression(
                         exp.Property,
@@ -862,6 +865,11 @@ class Parser:
                     "qualify": self._parse_qualify(),
                     "window": self._match(TokenType.WINDOW)
                     and self._parse_window(self._parse_id_var(), alias=True),
+                    "distribute": self._parse_sort(
+                        TokenType.DISTRIBUTE_BY, exp.Distribute
+                    ),
+                    "sort": self._parse_sort(TokenType.SORT_BY, exp.Sort),
+                    "cluster": self._parse_sort(TokenType.CLUSTER_BY, exp.Cluster),
                     "order": self._parse_order(),
                     "limit": limit or self._parse_limit(),
                     "offset": self._parse_offset(),
@@ -878,6 +886,9 @@ class Parser:
             this = self.expression(
                 exp.Values, expressions=self._parse_csv(self._parse_value)
             )
+            alias = self._parse_table_alias()
+            if alias:
+                this = self.expression(exp.Subquery, this=this, alias=alias)
         else:
             this = None
 
@@ -892,6 +903,9 @@ class Parser:
             this=this,
             alias=alias,
             order=self._parse_order(),
+            distribute=self._parse_sort(TokenType.DISTRIBUTE_BY, exp.Distribute),
+            sort=self._parse_sort(TokenType.SORT_BY, exp.Sort),
+            cluster=self._parse_sort(TokenType.CLUSTER_BY, exp.Cluster),
             limit=self._parse_limit(),
             offset=self._parse_offset(),
         )
@@ -1094,7 +1108,7 @@ class Parser:
         return self.expression(exp.Where, this=self._parse_conjunction())
 
     def _parse_group(self):
-        if not self._match_by(TokenType.GROUP):
+        if not self._match(TokenType.GROUP_BY):
             return None
         return self.expression(
             exp.Group,
@@ -1131,13 +1145,21 @@ class Parser:
         return self.expression(exp.Qualify, this=self._parse_conjunction())
 
     def _parse_order(self, this=None):
-        if not self._match_by(TokenType.ORDER):
+        if not self._match(TokenType.ORDER_BY):
             return this
 
         return self.expression(
             exp.Order, this=this, expressions=self._parse_csv(self._parse_ordered)
         )
 
+    def _parse_sort(self, token_type, exp_class):
+        if not self._match(token_type):
+            return None
+
+        return self.expression(
+            exp_class, expressions=self._parse_csv(self._parse_ordered)
+        )
+
     def _parse_ordered(self):
         this = self._parse_conjunction()
         self._match(TokenType.ASC)
@@ -1300,7 +1322,7 @@ class Parser:
         if type_token:
             if this:
                 return self.expression(exp.Cast, this=this, to=type_token)
-            if not type_token.args.get("nested"):
+            if not type_token.args.get("expressions"):
                 self._retreat(index)
                 return self._parse_column()
             return type_token
@@ -1390,6 +1412,8 @@ class Parser:
         this = self._parse_field()
         if isinstance(this, exp.Identifier):
             this = self.expression(exp.Column, this=this)
+        elif not this:
+            return self._parse_bracket(this)
         this = self._parse_bracket(this)
 
         while self._match_set(self.COLUMN_OPERATORS):
@@ -1469,7 +1493,7 @@ class Parser:
             this = self._parse_extract()
         else:
             subquery_predicate = self.SUBQUERY_PREDICATES.get(token_type)
-            this = self._curr.text.upper()
+            this = self._curr.text
             self._advance(2)
 
             if subquery_predicate and self._curr.token_type in (
@@ -1480,7 +1504,7 @@ class Parser:
                 self._match_r_paren()
                 return this
 
-            function = self.FUNCTIONS.get(this)
+            function = self.FUNCTIONS.get(this.upper())
             args = self._parse_csv(self._parse_lambda)
 
             if function:
@@ -1750,7 +1774,7 @@ class Parser:
 
         alias = self._parse_id_var(False)
 
-        if self._match_by(TokenType.PARTITION):
+        if self._match(TokenType.PARTITION_BY):
             partition = self._parse_csv(self._parse_type)
 
         order = self._parse_order()
@@ -1959,13 +1983,6 @@ class Parser:
         if not self._match(TokenType.R_PAREN):
             self.raise_error("Expecting )")
 
-    def _match_by(self, token_type):
-        if self._match(token_type):
-            if not self._match(TokenType.BY):
-                self.raise_error("Expecting BY")
-            return True
-        return False
-
     def _replace_columns_with_dots(self, this):
         if isinstance(this, exp.Dot):
             exp.replace_children(this, self._replace_columns_with_dots)
