@@ -72,6 +72,7 @@ class TokenType(AutoName):
     DATETIME = auto()
     DATE = auto()
     UUID = auto()
+    GEOGRAPHY = auto()
 
     # keywords
     ADD_FILE = auto()
@@ -87,12 +88,12 @@ class TokenType(AutoName):
     BEGIN = auto()
     BETWEEN = auto()
     BUCKET = auto()
-    BY = auto()
     CACHE = auto()
     CALL = auto()
     CASE = auto()
     CAST = auto()
     CHARACTER_SET = auto()
+    CLUSTER_BY = auto()
     COLLATE = auto()
     COMMENT = auto()
     COMMENT_END = auto()
@@ -105,12 +106,14 @@ class TokenType(AutoName):
     CURRENT_DATE = auto()
     CURRENT_DATETIME = auto()
     CURRENT_ROW = auto()
+    CURRENT_TIME = auto()
     CURRENT_TIMESTAMP = auto()
     DIV = auto()
     DEFAULT = auto()
     DELETE = auto()
     DESC = auto()
     DISTINCT = auto()
+    DISTRIBUTE_BY = auto()
     DROP = auto()
     ELSE = auto()
     END = auto()
@@ -123,13 +126,14 @@ class TokenType(AutoName):
     FALSE = auto()
     FETCH = auto()
     FILTER = auto()
+    FINAL = auto()
     FIRST = auto()
     FOLLOWING = auto()
     FOREIGN_KEY = auto()
     FULL = auto()
     FUNCTION = auto()
     FROM = auto()
-    GROUP = auto()
+    GROUP_BY = auto()
     GROUPING_SETS = auto()
     HAVING = auto()
     HINT = auto()
@@ -160,7 +164,7 @@ class TokenType(AutoName):
     ONLY = auto()
     OPTIMIZE = auto()
     OPTIONS = auto()
-    ORDER = auto()
+    ORDER_BY = auto()
     ORDERED = auto()
     ORDINALITY = auto()
     OUTER = auto()
@@ -168,6 +172,8 @@ class TokenType(AutoName):
     OVER = auto()
     OVERWRITE = auto()
     PARTITION = auto()
+    PARTITION_BY = auto()
+    PARTITIONED_BY = auto()
     PERCENT = auto()
     PLACEHOLDER = auto()
     PRECEDING = auto()
@@ -190,6 +196,7 @@ class TokenType(AutoName):
     SET = auto()
     SHOW = auto()
     SOME = auto()
+    SORT_BY = auto()
     STORED = auto()
     STRUCT = auto()
     TABLE_SAMPLE = auto()
@@ -336,13 +343,13 @@ class Tokenizer(metaclass=_Tokenizer):
         "BEGIN": TokenType.BEGIN,
         "BETWEEN": TokenType.BETWEEN,
         "BUCKET": TokenType.BUCKET,
-        "BY": TokenType.BY,
         "CALL": TokenType.CALL,
         "CACHE": TokenType.CACHE,
         "UNCACHE": TokenType.UNCACHE,
         "CASE": TokenType.CASE,
         "CAST": TokenType.CAST,
         "CHARACTER SET": TokenType.CHARACTER_SET,
+        "CLUSTER BY": TokenType.CLUSTER_BY,
         "COLLATE": TokenType.COLLATE,
         "COMMENT": TokenType.SCHEMA_COMMENT,
         "COMMIT": TokenType.COMMIT,
@@ -358,6 +365,7 @@ class Tokenizer(metaclass=_Tokenizer):
         "DELETE": TokenType.DELETE,
         "DESC": TokenType.DESC,
         "DISTINCT": TokenType.DISTINCT,
+        "DISTRIBUTE BY": TokenType.DISTRIBUTE_BY,
         "DROP": TokenType.DROP,
         "ELSE": TokenType.ELSE,
         "END": TokenType.END,
@@ -376,7 +384,7 @@ class Tokenizer(metaclass=_Tokenizer):
         "FOLLOWING": TokenType.FOLLOWING,
         "FOREIGN KEY": TokenType.FOREIGN_KEY,
         "FROM": TokenType.FROM,
-        "GROUP": TokenType.GROUP,
+        "GROUP BY": TokenType.GROUP_BY,
         "GROUPING SETS": TokenType.GROUPING_SETS,
         "HAVING": TokenType.HAVING,
         "IF": TokenType.IF,
@@ -406,14 +414,15 @@ class Tokenizer(metaclass=_Tokenizer):
         "OPTIMIZE": TokenType.OPTIMIZE,
         "OPTIONS": TokenType.OPTIONS,
         "OR": TokenType.OR,
-        "ORDER": TokenType.ORDER,
+        "ORDER BY": TokenType.ORDER_BY,
         "ORDINALITY": TokenType.ORDINALITY,
         "OUTER": TokenType.OUTER,
         "OUT OF": TokenType.OUT_OF,
         "OVER": TokenType.OVER,
         "OVERWRITE": TokenType.OVERWRITE,
         "PARTITION": TokenType.PARTITION,
-        "PARTITIONED": TokenType.PARTITION,
+        "PARTITION BY": TokenType.PARTITION_BY,
+        "PARTITIONED BY": TokenType.PARTITIONED_BY,
         "PERCENT": TokenType.PERCENT,
         "PRECEDING": TokenType.PRECEDING,
         "PRIMARY KEY": TokenType.PRIMARY_KEY,
@@ -432,6 +441,7 @@ class Tokenizer(metaclass=_Tokenizer):
         "SET": TokenType.SET,
         "SHOW": TokenType.SHOW,
         "SOME": TokenType.SOME,
+        "SORT BY": TokenType.SORT_BY,
         "STORED": TokenType.STORED,
         "TABLE": TokenType.TABLE,
         "TBLPROPERTIES": TokenType.PROPERTIES,
@@ -632,19 +642,41 @@ class Tokenizer(metaclass=_Tokenizer):
                 self._add(TokenType.STRING)
 
     def _scan_keywords(self):
-        size = 1
+        size = 0
         word = None
         chars = self._text
+        char = chars
+        prev_space = False
+        skip = False
+        trie = self.KEYWORD_TRIE
 
         while chars:
-            result = in_trie(self.KEYWORD_TRIE, chars.upper())
+            if skip:
+                result = 1
+            else:
+                result, trie = in_trie(trie, char.upper())
 
             if result == 0:
                 break
             if result == 2:
                 word = chars
             size += 1
-            chars = self._chars(size)
+            end = self._current - 1 + size
+
+            if end < self.size:
+                char = self.sql[end]
+                is_space = char in self.WHITE_SPACE
+
+                if not is_space or not prev_space:
+                    if is_space:
+                        char = " "
+                    chars += char
+                    prev_space = is_space
+                    skip = False
+                else:
+                    skip = True
+            else:
+                chars = None
 
         if not word:
             if self._char in self.SINGLE_TOKENS:
@@ -662,7 +694,7 @@ class Tokenizer(metaclass=_Tokenizer):
         if self._scan_string(word):
             return
 
-        self._advance(len(word) - 1)
+        self._advance(size - 1)
         self._add(self.KEYWORDS[word.upper()])
 
     def _scan_comment(self, comment):
@@ -732,7 +764,7 @@ class Tokenizer(metaclass=_Tokenizer):
 
         while True:
             if self._char == self.escape and self._peek == quote:
-                text += f"{self.ESCAPE_CODE}{self._char}"
+                text += f"{self.ESCAPE_CODE}{self._peek}"
                 self._advance(2)
             else:
                 if self._chars(size) == quote:
@@ -741,7 +773,7 @@ class Tokenizer(metaclass=_Tokenizer):
                     break
 
                 if self._char == "'":
-                    text += f"{self.ESCAPE_CODE}{self._char}"
+                    text += f"{self.ESCAPE_CODE}'"
                     self._advance()
                 elif self._end:
                     raise RuntimeError(
